@@ -9,10 +9,9 @@ predict.glmnet=function(object,newx,s=NULL,type=c("link","response","coefficient
     which=match(s,lambda,FALSE)
     if(!all(which>0)){
       lambda=unique(rev(sort(c(s,lambda))))
-      object=update(object,lambda=lambda)
+      object=tryCatch(update(object,lambda=lambda,...),error=function(e)stop("problem with predict.glmnet() or coef.glmnet(): unable to refit the glmnet object to compute exact coefficients; please supply original data by name, such as x and y, plus any weights, offsets etc.",call.=FALSE))
     }
-  }
-    
+  } 
   a0=t(as.matrix(object$a0))
   rownames(a0)="(Intercept)"
   nbeta=rbind2(a0,object$beta)
@@ -21,7 +20,8 @@ predict.glmnet=function(object,newx,s=NULL,type=c("link","response","coefficient
     dimnames(nbeta)=list(NULL,NULL)
     lambda=object$lambda
     lamlist=lambda.interp(lambda,s)
-    nbeta=nbeta[,lamlist$left,drop=FALSE]*lamlist$frac +nbeta[,lamlist$right,drop=FALSE]*(1-lamlist$frac)
+    
+    nbeta=nbeta[,lamlist$left,drop=FALSE]%*%Diagonal(x=lamlist$frac) +nbeta[,lamlist$right,drop=FALSE]%*%Diagonal(x=1-lamlist$frac)
     dimnames(nbeta)=list(vnames,paste(seq(along=s)))
   }
   if(type=="coefficients")return(nbeta)
