@@ -13,7 +13,8 @@ predict.multnet <-
     which=match(s,lambda,FALSE)
     if(!all(which>0)){
       lambda=unique(rev(sort(c(s,lambda))))
-      object=update(object,lambda=lambda)
+      ### Now we check if x and y were supplied; if not, we try
+      object=tryCatch(update(object,lambda=lambda,...),error=function(e)stop("problem with predict.glmnet() or coef.glmnet(): unable to refit the glmnet object to compute exact coefficients; please supply original data by name, such as x and y, plus any weights, offsets etc.",call.=FALSE))
     }
   }
 
